import setuptools

setuptools.setup(
    name="st-searchbar",
    version="0.0.8",
    author=" Asvin Ragunathan",
    author_email="r.asvin@hotmail.com",
    description="A search bar component for streamlit with audio input and suggestions.",
    long_description="",
    long_description_content_type="text/plain",
    url="",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        "streamlit >= 0.63",
    ],
)
